/// <reference types="vite/client" />
import filters from '@/filters'

declare module '*.vue' {
  import { DefineComponent } from 'vue'
  // eslint-disable-next-line
  const component: DefineComponent<{}, {}, any>
  export default component
}

declare module 'vue' {
  interface ComponentCustomProperties {
    $filters: typeof filters
  }
}

interface ImportMeta {
  readonly env: ImportMetaEnv
}

interface ImportMetaEnv {
  readonly VITE_APP_NAME: string
  readonly VITE_APP_LOGO: string
  readonly VITE_APP_URL: string
  readonly VITE_APP_I18N_LOCALE: string
  readonly VITE_APP_AXIOS_BASE_URL: string
  readonly VITE_APP_DOCUMENTATION_URL: string
  readonly VITE_APP_MATOMO_SERVER: string
  readonly VITE_APP_MATOMO_SITE_ID: string
  readonly VITE_APP_MATOMO_DEBUG: string
  readonly VITE_APP_PROJECT_CREATION_FORM_URL: string
}

declare module 'vue-matomo' {

  import { RouteLocationNormalized, Router } from 'vue-router'

  import { App } from 'vue'

  declare type DefaultOptions = {

    debug: boolean;

    disableCookies: boolean;

    enableHeartBeatTimer: boolean;

    enableLinkTracking: boolean;

    heartBeatTimerInterval: number;

    requireConsent: boolean;

    trackInitialView: boolean;

    trackerFileName: string;

    trackerUrl?: string;

    trackerScriptUrl?: string;

    userId?: string;

    cookieDomain?: string;

    domains?: string;

    preInitActions: string[][];

  }

  declare type MatomoSetupOptions = {

    host: string;

    siteId: number;

    router: Router;

    trackerFileName?: string;

    trackerUrl?: string;

    trackerScriptUrl?: string;

    enableLinkTracking?: boolean;

    requireConsent?: boolean;

    trackInitialView?: boolean;

    disableCookies?: boolean;

    enableHeartBeatTimer?: boolean;

    heartBeatTimerInterval?: number;

    debug?: boolean;

    domains?: string;

    preInitActions?: string[][];

  }

  interface MatomoTracker {

    setReferrerUrl(referrerUrl: string): void;

    setCustomUrl(url: string): void;

    trackPageView(title: string): void;

    enableLinkTracking(): void;

  }

  declare type MatomoOptions = DefaultOptions | MatomoSetupOptions;

  const defaultOptions: DefaultOptions

  const matomoKey: string

  function trackMatomoPageView(options: MatomoOptions,

                               to: RouteLocationNormalized,

                               from: RouteLocationNormalized,

  ): void | undefined;

  function initMatomo(Vue: App, options: MatomoOptions): void;

  function piwikExists(): Promise<void | never>;

  function install(Vue: App, setupOptions?: MatomoSetupOptions): void;

  function getMatomo(): MatomoTracker;

  function loadScript(trackerScript: string): Promise<void>;

  function getResolvedHref(router: Router, path: string): string;

}
