import { it, expect, describe, beforeEach, vi } from 'vitest'
import { mount } from '@vue/test-utils'
import { Quasar } from 'quasar'
import { i18n, t } from '@/plugins/i18n'
import ConfirmBox from '@/components/common/ConfirmBox.vue'
import { defineComponent, nextTick } from 'vue'
import type { TestWrapper } from '../../types'

type PropsType = {
  isOpen?: boolean;
  object?: string;
  action?: string;
  confirmAction: Function;
}

const ConfirmBoxTester = defineComponent({
  template: `
    <div>
      <button @click="isOpen = true"></button>
      <ConfirmBox
          :is-open="isOpen"
          :object="object"
          :action="action"
          @confirm="confirmAction"
      />
    </div>
  `,
  components: {ConfirmBox},
  props: ['isOpen', 'object', 'action', 'confirmAction'],
})

const confirmAction = vi.fn()


describe.skip('ConfirmBox', () => {
  let wrapper: TestWrapper<{isOpen: boolean}>
  const mountComponent = (componentProps: Partial<PropsType>) => {
    wrapper = mount(
        ConfirmBoxTester,
        {
          global: {
            plugins: [i18n, Quasar]
          },
          props: {
            ...componentProps,
            confirmAction
          },
        }
    )
  }
  describe('dialog content', () => {
    const object = ''
    beforeEach(() => {
      mountComponent({isOpen: true, object})
    })
    describe('title', () => {
      it('should default to deletion confirmation', () => {
        const box = wrapper.findComponent(ConfirmBox)
        expect(box.exists()).toBe(true)
        const deleteText = t('confirm.delete', {object})
        expect(wrapper.text()).toContain(deleteText)
      })
    })
  })
  describe('open&close dialog', () => {
    it('should be closed by default', () => {
      mountComponent({})
      expect(wrapper.findComponent(ConfirmBox).vm.isOpen).to.be.false
    })
    it('should open on click', async () => {
      mountComponent({})
      await wrapper.find('button').trigger('click')
      await nextTick()
      expect(wrapper.findComponent(ConfirmBox).vm.isOpen).to.be.true
    })
  })
})
